__title__ = "butterfly"
__version__ = "3.1.0"

__summary__ = "A sleek web based terminal emulator"
__uri__ = "https://github.com/paradoxxxzero/butterfly"
__author__ = "Florian Mounier"
__email__ = "paradoxxx.zero@gmail.com"

__license__ = "GPLv3"
__copyright__ = "Copyright 2017 %s" % __author__
