/* Snazzy from https://github.com/sindresorhus/iterm2-snazzy */
$fg: #eff0eb
$bg: #282a36
$active-bg: $bg

$colors: #282a36, #ff5c57, #5af78e, #f3f99d, #57c7ff, #ff6ac1, #9aedfe, #f1f1f0, #686868, #ff5c57, #5af78e, #f3f99d, #57c7ff, #ff6ac1, #9aedfe, #eff0eb

@import variables
@import styles
